"use strict";

exports.__esModule = true;
exports.Script = Script;
exports.ScriptStrategy = void 0;

var _react = _interopRequireWildcard(require("react"));

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

var ScriptStrategy; // eslint-disable-next-line @typescript-eslint/naming-convention

exports.ScriptStrategy = ScriptStrategy;

(function (ScriptStrategy) {
  ScriptStrategy["preHydrate"] = "pre-hydrate";
  ScriptStrategy["postHydrate"] = "post-hydrate";
  ScriptStrategy["idle"] = "idle";
})(ScriptStrategy || (exports.ScriptStrategy = ScriptStrategy = {}));

function Script(props) {
  var _ref = props || {},
      src = _ref.src,
      _ref$strategy = _ref.strategy,
      strategy = _ref$strategy === void 0 ? ScriptStrategy.postHydrate : _ref$strategy;

  (0, _react.useEffect)(function () {
    switch (strategy) {
      case ScriptStrategy.postHydrate:
        injectScript(props);
        break;

      case ScriptStrategy.idle:
        requestIdleCallback(function () {
          injectScript(props);
        });
        break;

      default:
        return;
    }
  }, []);

  if (strategy === ScriptStrategy.preHydrate) {
    var inlineScript = resolveInlineScript(props);

    if (inlineScript) {
      return /*#__PURE__*/_react.default.createElement("script", {
        async: true,
        "data-strategy": strategy
      }, resolveInlineScript(props));
    }

    return /*#__PURE__*/_react.default.createElement("script", {
      async: true,
      src: src,
      "data-strategy": strategy
    });
  }

  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null);
}

function injectScript(props) {
  var _ref2 = props || {},
      src = _ref2.src,
      _ref2$strategy = _ref2.strategy,
      strategy = _ref2$strategy === void 0 ? ScriptStrategy.postHydrate : _ref2$strategy;

  var inlineScript = resolveInlineScript(props);
  var script = document.createElement("script");
  script.dataset.strategy = strategy;

  if (inlineScript) {
    script.textContent = inlineScript;
  }

  if (src) {
    script.src = src;
  }

  document.body.appendChild(script);
}

function resolveInlineScript(props) {
  var _ref3 = props || {},
      dangerouslySetInnerHTML = _ref3.dangerouslySetInnerHTML,
      _ref3$children = _ref3.children,
      children = _ref3$children === void 0 ? "" : _ref3$children;

  var _ref4 = dangerouslySetInnerHTML || {},
      _ref4$__html = _ref4.__html,
      dangerousHTML = _ref4$__html === void 0 ? "" : _ref4$__html;

  return dangerousHTML || children;
}